# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 2025-09-15 - 0.1.2

### Added
- Initial release of ymago
- Image generation with Google Gemini models
- Video generation with Google Veo models
- CLI interface with rich output
- Async architecture for high performance
- Configurable via TOML files and environment variables
- Cloud Integration: Cloudflare R2,  Google Cloud Storage or AWS S3
- Webhook Notifications